'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.stylePropType = undefined;

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _aphrodite = require('aphrodite');

var _compose = require('recompose/compose');

var _compose2 = _interopRequireDefault(_compose);

var _withState = require('recompose/withState');

var _withState2 = _interopRequireDefault(_withState);

var _lifecycle = require('recompose/lifecycle');

var _lifecycle2 = _interopRequireDefault(_lifecycle);

require('./index.css');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var stylePropType = exports.stylePropType = _propTypes2.default.oneOfType([_propTypes2.default.object, _propTypes2.default.arrayOf(_propTypes2.default.object)]);

var styles = void 0;
var iconLib = {};
var widthHeightRe = /<svg width="([^"]+)" height="([^"]+)"/;
var viewBoxRe = /viewBox="([^"]+)"/;
var idRe = /<g id="(icon-[^"]+)"/;

var enhance = (0, _compose2.default)((0, _withState2.default)('iconMeta', 'setIconMeta', null), (0, _lifecycle2.default)({
  componentWillMount: function componentWillMount() {
    var _this = this;

    var src = this.props.src;


    if (Reflect.has(iconLib, src)) {
      // If the value is a promise, the icon is being fetched. Wait for it
      if (typeof iconLib[src].then === 'function') {
        iconLib[src].then(function () {
          return _this.props.setIconMeta(iconLib[src]);
        });
      } else {
        // Icon is already loaded
        this.props.setIconMeta(iconLib[src]);
      }
    } else {
      iconLib[src] = fetch(src, {
        method: 'GET',
        credentials: 'include',
        headers: { accept: 'image/webp,image/apng,image/*,*/*;q=0.8' }
      }).then(function (response) {
        return response.text();
      }).then(function (contents) {
        var vhMatch = contents.match(widthHeightRe);
        var viewBoxMatch = contents.match(viewBoxRe);
        var idMatch = contents.match(idRe);

        var meta = {};
        if (!idMatch) {
          // Error case. Not able to show the icon
          meta.error = true;
          return;
        }
        meta.id = idMatch[1];

        if (vhMatch) {
          meta.width = vhMatch[1];
          meta.height = vhMatch[2];
        }

        if (viewBoxMatch) {
          meta.viewBox = viewBoxMatch[1];
        } else if (vhMatch) {
          meta.viewBox = '0 0 ' + meta.width.replace('px', '') + ' ' + meta.height.replace('px', '');
        } else {
          // Error case. Not able to show the icon
          meta.error = true;
        }

        if (!meta.error) {
          var container = document.querySelector('#react-svg-icon-repo');
          if (!container) {
            container = document.createElement('div');
            container.setAttribute('id', 'react-svg-ikon-repo');
            container.setAttribute('style', 'display:none');
            document.body.appendChild(container);
          }
          container.innerHTML = container.innerHTML + ' ' + contents;
          iconLib[src] = meta;
          _this.props.setIconMeta(meta);
        }
      });
    }
  }
}));

var Icon = function Icon(_ref) {
  var iconMeta = _ref.iconMeta,
      style = _ref.style,
      fill = _ref.fill,
      stroke = _ref.stroke,
      className = _ref.className;

  if (iconMeta === null) {
    return null;
  }

  if (iconMeta.error) {
    return _react2.default.createElement(
      'div',
      { className: (0, _aphrodite.css)(styles.errorContainer) },
      '?'
    );
  }

  var baseClassName = 'icon-container ' + (fill && !stroke ? 'fill' : '') + ' ' + (stroke ? 'stroke' : '') + ' ' + className;
  var finalStyle = void 0;
  if (stroke) {
    finalStyle = { color: stroke };
  } else if (fill) {
    finalStyle = { color: fill };
  }

  var svgStyle = {
    width: style && style.width || iconMeta.width,
    height: style && style.height || iconMeta.height
  };

  return _react2.default.createElement(
    'div',
    {
      className: baseClassName + ' ' + (0, _aphrodite.css)(styles.container, style),
      style: finalStyle
    },
    _react2.default.createElement(
      'svg',
      { viewBox: iconMeta.viewBox, style: svgStyle },
      _react2.default.createElement('use', { xlinkHref: '#' + iconMeta.id })
    )
  );
};

Icon.propTypes = {
  src: _propTypes2.default.string.isRequired, // eslint-disable-line
  iconMeta: _propTypes2.default.shape({
    viewBox: _propTypes2.default.string.isRequired,
    error: _propTypes2.default.bool
  }),
  style: stylePropType,
  fill: _propTypes2.default.string,
  stroke: _propTypes2.default.string,
  className: _propTypes2.default.string
};

Icon.defaultProps = {
  iconMeta: null,
  style: null,
  fill: null,
  stroke: null,
  className: ''
};

styles = _aphrodite.StyleSheet.create({
  container: {
    display: 'flex',
    alignItems: 'center',
    justifyContent: 'center'
  },

  errorContainer: {
    width: '2rem',
    height: '2rem',
    border: '1px solid #999999',
    borderRadius: '50%',
    display: 'flex',
    alignItems: 'center',
    justifyContent: 'center'
  }
});

exports.default = enhance(Icon);